summaryrefslogtreecommitdiffstatshomepage
path: root/src/lib/formats/wd177x_dsk.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib/formats/wd177x_dsk.cpp')
-rw-r--r--src/lib/formats/wd177x_dsk.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/lib/formats/wd177x_dsk.cpp b/src/lib/formats/wd177x_dsk.cpp
index da900b03db5..75f3396020f 100644
--- a/src/lib/formats/wd177x_dsk.cpp
+++ b/src/lib/formats/wd177x_dsk.cpp
@@ -441,8 +441,8 @@ void wd177x_format::check_compatibility(floppy_image *image, std::vector<int> &c
int max_tracks, max_heads;
image->get_maximal_geometry(max_tracks, max_heads);
- // Fail if floppy drive can't handle track count
- if(f.track_count > max_tracks) {
+ // Fail if floppy drive can't handle track or head count
+ if(f.track_count > max_tracks || f.head_count > max_heads) {
goto fail;
}